package com.xinda.itsm.service.impl;

import java.util.List;
import com.xinda.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.xinda.itsm.mapper.PrePlanMapper;
import com.xinda.itsm.domain.PrePlan;
import com.xinda.itsm.service.IPrePlanService;

/**
 * 预案管理Service业务层处理
 * 
 * @author kerwincui
 * @date 2025-04-27
 */
@Service
public class PrePlanServiceImpl implements IPrePlanService 
{
    @Autowired
    private PrePlanMapper prePlanMapper;

    /**
     * 查询预案管理
     * 
     * @param prePlanId 预案管理主键
     * @return 预案管理
     */
    @Override
    public PrePlan selectPrePlanByPrePlanId(Long prePlanId)
    {
        return prePlanMapper.selectPrePlanByPrePlanId(prePlanId);
    }

    /**
     * 查询预案管理列表
     * 
     * @param prePlan 预案管理
     * @return 预案管理
     */
    @Override
    public List<PrePlan> selectPrePlanList(PrePlan prePlan)
    {
        return prePlanMapper.selectPrePlanList(prePlan);
    }

    /**
     * 新增预案管理
     * 
     * @param prePlan 预案管理
     * @return 结果
     */
    @Override
    public int insertPrePlan(PrePlan prePlan)
    {
        prePlan.setCreateTime(DateUtils.getNowDate());
        return prePlanMapper.insertPrePlan(prePlan);
    }

    /**
     * 修改预案管理
     * 
     * @param prePlan 预案管理
     * @return 结果
     */
    @Override
    public int updatePrePlan(PrePlan prePlan)
    {
        prePlan.setUpdateTime(DateUtils.getNowDate());
        return prePlanMapper.updatePrePlan(prePlan);
    }

    /**
     * 批量删除预案管理
     * 
     * @param prePlanIds 需要删除的预案管理主键
     * @return 结果
     */
    @Override
    public int deletePrePlanByPrePlanIds(Long[] prePlanIds)
    {
        return prePlanMapper.deletePrePlanByPrePlanIds(prePlanIds);
    }

    /**
     * 删除预案管理信息
     * 
     * @param prePlanId 预案管理主键
     * @return 结果
     */
    @Override
    public int deletePrePlanByPrePlanId(Long prePlanId)
    {
        return prePlanMapper.deletePrePlanByPrePlanId(prePlanId);
    }
}
